@@ -149,13 +149,16 @@ def compact_using_oracle(datasets_info: Union[du.DataInfo, Iterable[du.DataInfo]
                          model_builder_class: ModelBuilderBase,
                          oracle: Union[Callable, Dict[str, du.UncertaintyInfo]],
                          task_dir: str, overwrite: bool=False,
-                         poolsize: int=-1, runs: int=1,
-                         model_init_info: Optional[Dict]=None, oracle_params: Optional[Dict]=None,
-                         flatten=True, max_components: int=500, scale: float=10000,
-                         min_sample_size:int=400, min_sample_size_per_dist: int=200,
+                         poolsize: int = -1, runs: int = 1,
+                         model_init_info: Optional[Dict] = None, oracle_params: Optional[Dict] = None,
+                         flatten=True, max_components: int = 500, scale: float = 10000,
+                         min_sample_size: int = 400, min_sample_size_per_dist: int = 200,
                          max_sample_size: Optional[int] = None,
-                         sampling_trials: int=3,
-                         save_optimal_sample:bool=False):
+                         sampling_trials: int = 3,
+                         use_weights: bool = False, num_weight_trials: int = 10,
+                         save_optimal_sample: bool = False,
+                         optimizer: str = 'hyperopt',
+                         optimizer_params: dict = None):
     """
     This is the main entry function for a user.
 
@@ -214,9 +217,17 @@ def compact_using_oracle(datasets_info: Union[du.DataInfo, Iterable[du.DataInfo]
         and passing in only the reduced dataset.
     :param sampling_trials: the number of model fits the optimizer performs within each iteration. Option provided for
         robustness.
+    :param use_weights: you can avoid sampling and fitting (which can be expensive) by using instance weights instead,
+        IF your classifier supports learning using instance weights. If this is set to True, sampling_trials MUST be
+        set to 1
+    :param num_weight_trials: if use_weights is True, this is the number of times instance weights would be averaged
     :param save_optimal_sample: whether the optimal sample found should be saved. Note this would save the optimal
         sample for all model complexity+dataset combinations. This is helpful for post-hoc analysis of the
         optimal sample.
+    :param optimizer: optimizer backend to use, currently supported "hyperopt" (default) or "pysot"
+    :param optimizer_params: if the optimizer accepts params, they need to be passed in as a dict. There is no standard
+        format for this, and would be parsed in an optimizer specific way. Current supported:
+        * for optimizer=pysot, this parameter can be {"strategy": "srbf"} or {"strategy": "dycors"}
 
     :return: dataframe of results aggregated across runs.
     """
@@ -233,7 +244,7 @@ def compact_using_oracle(datasets_info: Union[du.DataInfo, Iterable[du.DataInfo]
                             f"use it anyway.")
         else:
             notif_msg = f"Provided output directory '{task_dir}' is not empty, will abort. If you want to" \
-                        f"use a non-empty directory anyway, set the overwrite parameter to True."
+                        f" use a non-empty directory anyway, set the overwrite parameter to True."
             logging.error(notif_msg)
             print(notif_msg)
             raise ValueError
@@ -441,7 +452,11 @@ def compact_using_oracle(datasets_info: Union[du.DataInfo, Iterable[du.DataInfo]
                              'max_components': max_components,
                              'scale': scale,
                              'compute_all_baselines': False,
-                             'save_optimal_sample': save_optimal_sample
+                             'save_optimal_sample': save_optimal_sample,
+                             'optimizer': optimizer,
+                             'optimizer_params': optimizer_params,
+                             'use_weights': use_weights,
+                             'num_weight_trials': num_weight_trials
                              }
                 run_expt_args.append(expt_args)
 
